function [vWeights,vMetric] = GetWeights_Template( cPoints, cPointsIdxs,cCenter, cExtraParam )

%
% function [vWeights,vMetric] = GetWeights_Template( cPoints, cPointsIdxs,cCenter, cExtraParam )
%
% IN:
%   cPoints     : M points in N dimensions in a M by N matrix (typically the whole dataset)
%   cPointsIdxs : K indices (into cPoints) of the points involved in the weights computation
%   cCenter     : Row vector representing the point from which to compute the weights to the cPoints(cPointsIdxs,:)
%   cExtraParam : parameters for the weights calculation (dependent on such calculation)
%
% OUT:
%   vWeights    : K column vector, i-th entry being the weight from cCenter to cPoints(cPointsIdxs(lk),:)
%   vMetric     : When it applies, returns a structure containing info about the metric
%
% USES:
%   nothing
%



